Add Coalescent Lag to Transmission Distances
Source:R/add_coalescent_distance.R
add_coalescent_distance.RdAugments a transmission distance matrix with stochastic coalescent distances to simulate the divergence between a transmission tree and a gene tree.